@@ -2,13 +2,14 @@ package CPAN::Digger;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Capture::Tiny qw(capture);
 use Log::Log4perl ();
 use File::Temp qw(tempdir);
 use Cwd qw(getcwd);
 use Exporter qw(import);
+use LWP::UserAgent ();
 use Data::Dumper qw(Dumper);
 use File::Spec ();
 use Log::Log4perl ();
@@ -22,13 +23,13 @@ my $tempdir = tempdir( CLEANUP => 1 );
 
 my %known_licenses = map {$_ => 1} qw(perl_5);
 
-
 sub new {
     my ($class, %args) = @_;
     my $self = bless {}, $class;
     for my $key (keys %args) {
         $self->{$key} = $args{$key};
     }
+    $self->{log} = uc $self->{log};
 
     $self->{db} = CPAN::Digger::DB->new(db => $self->{db});
 
@@ -101,6 +102,22 @@ sub analyze_github {
     my $repo_name = (split '\/', $vcs_url)[-1];
     $logger->info("Analyze GitHub repo '$vcs_url' in directory $repo_name");
 
+    my $ua = LWP::UserAgent->new(timeout => 5, max_redirect => 0);
+    my $response = $ua->get($vcs_url);
+    if ($response->status_line eq '404 Not Found') {
+        $logger->error("Repository '$vcs_url' Received 404 Not Found. Please update the link in the META file");
+        return;
+    }
+    if ($response->status_line eq '301 Moved Permanently') {
+        $logger->error("Repository '$vcs_url' is being redirected. Please update the link in the META file");
+        return;
+    }
+    my $status_line = $response->status_line;
+    if ($response->status_line ne '200 OK') {
+        $logger->error("Repository '$vcs_url'  got a response of '$status_line'. Please report this to the maintainer of CPAN::Digger.");
+        return;
+    }
+
     my $git = 'git';
 
     my @cmd = ($git, "clone", "--depth", "1", $data->{vcs_url});
